#!/etc/opt/openit/perl -w

use strict;


my @filters=( "license-individual-usage-v2.conf",
	      "license-host-usage-v2.conf",
	      "license-host-user-usage.conf",
	      "license-individual-usage-v2-sam.conf",
	      "license-host-usage-v2-sam.conf",
	      "license-host-user-usage-sam.conf",
	      "license-individual-queued.conf" );

&verify_root();

foreach my $filter (@filters) {
    update_filter($filter);
}

exit 0;

sub update_filter {
    my ($filter) = @_;

    my $file = "/var/opt/openit/etc/filtrator/$filter";
    my $old  = "$file.old";
    my $new  = "$file.new";

    # Check that file exists
    if (! -r $file) {
	print "Skipping non-existing filter '$filter'\n";
	return;
    }

    # Read config file into array
    open(IN,  "<$file") || die "Error: Unable to read old file '$file'!\n";    
    my @config = <IN>;
    close(IN);

    # Do updates ( mark changes )

    #
    # Find the compare object in concurrent filter
    #
    my $ind = 0;
    while( $ind < scalar(@config) && $config[$ind] !~ /concurrent/i) {$ind++};
    $ind++;
    while( $ind < scalar(@config) && $config[$ind] !~ /concurrent/i) {$ind++};
    $ind++;
    while( $ind < scalar(@config) && $config[$ind] !~ /compare/i) {$ind++};
    if (! ($config[$ind] =~ s/,licenses//)) { # No changes needed
	unlink $new; #
	print "Skipping update of '$filter' (already done)!\n";
	return;
    }

    # Write output
    open(OUT, ">$new")  || die "Error: Can't write new file '$new'!\n";
    foreach my $line (@config) {
	print OUT $line;
    }
    close(OUT);

    if( ! rename($file, $old)) {
	die "Error: Unable to previous config to '$old'!\n";
    }

    if( ! rename($new, $file)) {
	die "Error: Unable to rename new config to '$file'!\n";
    }

    print "Updated filter '$filter'\n";
}


sub verify_root {
    # Only root can patch
    if ( $< ne 0 ) {
	die "Error: Patching must be done as 'root'!\n";
    }
}

